@@ -11,11 +11,9 @@
 #' @export
 #' @importFrom tidyr nest spread
 #' @importFrom purrr when map2_dbl
-#' @importFrom dplyr group_by
+#' @importFrom dplyr mutate select group_by
 #' @keywords internal
 #' @examples
-#'
-#'
 #' \dontrun{
 #' radf_psy1 <- radf(sim_psy1(100))
 #'
@@ -29,10 +27,8 @@
 #' sb_psy1 <- radf_sb_distr(sim_data)
 #'
 #' calc_pvalue(radf(sim_data), sb_psy1)
-#'
 #' }
 calc_pvalue <- function(x, distr = NULL) {
-
   assert_class(x, "radf_obj")
   if (is.null(distr)) {
     message_glue("Using `radf_mc_distr` for `distr`.")
@@ -43,7 +39,7 @@ calc_pvalue <- function(x, distr = NULL) {
     tbl_x <- tidy(x, panel = TRUE) %>%
       mutate(id = "panel", stat = "gsadf_panel") %>%
       nest(value_x = gsadf_panel)
-  } else{
+  } else {
     tbl_x <- tidy(x) %>%
       gather(stat, value_x, -id) %>%
       nest(value_x = value_x)
@@ -54,8 +50,8 @@ calc_pvalue <- function(x, distr = NULL) {
       group_by(stat) %>%
       nest(value_y = value_y)
     tbl_join_nested <-
-      full_join(tbl_x, tbl_distr, by = c("id","stat"))
-  }else{
+      full_join(tbl_x, tbl_distr, by = c("id", "stat"))
+  } else {
     tbl_distr <- tidy(distr) %>%
       gather(., stat, value_y) %>%
       group_by(stat) %>%
@@ -70,11 +66,7 @@ calc_pvalue <- function(x, distr = NULL) {
     mutate(pval = map2_dbl(value_x, value_y, xy_pvalue)) %>%
     select(id, stat, pval) %>%
     spread(stat, pval) %>%
-    {if (is_sb(distr)) . else select(., id, adf, sadf, gsadf)}
-
+    {
+      if (is_sb(distr)) . else select(., id, adf, sadf, gsadf)
+    }
 }
-
-
-
-
-
